import React from 'react';
import { connect } from 'dva';
import { calculateWinner } from '../services/example';
import Board from '../components/Board';
import style from './game.css';

const Game = ({ history, stepNumber, xIsNext, dispatch }) => {
  const current = history[stepNumber];
  const winner = calculateWinner(current.squares);
  const moves = history.map((step, move) => {
    const desc = move ?
      'Go to move #' + move :
      'Go to game start';
    return (
      <li key={move}>
          <button onClick={() => dispatch({type: 'game/jumpTo', payload: move})}>{desc}</button>
      </li>
    )
  });
  let status;
  if (winner) {
    status = "Winner: " + winner;
  } else {
    status = "Next player: " + (xIsNext ? "X" : "O");
  }
  return (
    <div className={style.game}>
      <div className="game-board">
        <Board
          squares={current.squares}
          dispatch={dispatch}
        />
      </div>
      <div className="game-info">
        <div>{status}</div>
        <ol>{moves}</ol>
      </div>
    </div>
  )
}
Game.propTypes = {
};
const mapStateToProps = (state) => {
  return {
    history: state.game.history,
    stepNumber: state.game.stepNumber,
    xIsNext: state.game.xIsNext
  }
}
export default connect(mapStateToProps)(Game);
